import styles from "../../styles";
import { colors } from "../../styles";
import { TransactionType } from "../Types/Types";
export interface props {
  transaction: TransactionType;
}

function StatusText(props: { status: string }) {
  let color;
  if (
    props.status === "Pending Approval" ||
    props.status === "Returned: Pending Checking"
  ) {
    color = colors.orange;
  } else if (
    props.status === "Approved" ||
    props.status === "Finalized" ||
    props.status === "Borrowed"
  ) {
    color = colors.green;
  } else {
    color = colors.red;
  }
  return (
    <p
      style={{
        ...styles.text_dark,
        ...styles.text_S,
        ...{
          textAlign: "center",
          color: color,
        },
      }}
    >
      {props.status}
    </p>
  );
}
export default function TransactionEntry(props: props) {
  return (
    <div
      style={{
        alignSelf: "center",
        justifySelf: "center",
        width: "384px",
        backgroundColor: colors.header_color,
        borderRadius: 16,
        margin: "8px",
        padding: "8px",
      }}
    >
      <div style={styles.flex_row}>
        <p
          style={{
            ...styles.text_dark,
            ...styles.text_S,
            ...{ textAlign: "left", flex: 1 },
          }}
        >
          ID: {props.transaction.id}
        </p>
        <p
          style={{
            ...styles.text_dark,
            ...styles.text_S,
            ...{ textAlign: "right", flex: 2 },
          }}
        >
          {props.transaction.timestamp}
        </p>
      </div>
      <div style={styles.flex_row}>
        <div style={{ flex: 1 }}>
          <p
            style={{
              ...styles.text_dark,
              ...styles.text_S,
              ...{ textAlign: "left", margin: 0 },
            }}
          >
            Borrower: {props.transaction.borrower.name}{" "}
            {`(ID:${props.transaction.borrower.id})`}
          </p>
          <p
            style={{
              ...styles.text_dark,
              ...styles.text_S,
              ...{ textAlign: "left", margin: 0 },
            }}
          >
            Teacher: {props.transaction.teacher.name}{" "}
            {`(ID:${props.transaction.teacher.id})`}
          </p>
          <p
            style={{
              ...styles.text_dark,
              ...styles.text_S,
              ...{
                height: "64px",
                textAlign: "left",
                margin: 0,
                marginTop: "8px",
                flexWrap: "wrap",
                overflowY: "scroll",
              },
            }}
          >
            {props.transaction.remarks}
          </p>
        </div>
        <div style={{ flex: 1 }}>
          <p
            style={{
              ...styles.text_dark,
              ...styles.text_S,
              ...{ textAlign: "right", margin: 0 },
            }}
          >
            Equipments:
          </p>
          <div
            style={{
              ...styles.flex_column,
              ...{ height: "96px", overflowY: "scroll" },
            }}
          >
            {props.transaction.equipments.map((equipment) => (
              <p
                style={{
                  ...styles.text_dark,
                  ...styles.text_S,
                  ...{
                    textAlign: "right",
                    margin: 0,
                    lineHeight: 0,
                  },
                }}
              >
                {` - ${equipment.name} (ID:${equipment.id})`}
              </p>
            ))}
          </div>
        </div>
      </div>
      <StatusText status={props.transaction.transaction_status} />
    </div>
  );
}
